      subroutine xskdc0 (ear,ne,param,ifl,photar,photer)

      implicit none

      integer ni,ngp,nc,ng,nr,np,nb
      parameter (ni=2,ngp=5,nc=2,ng=100,nr=100,np=5,nb=100)

      integer ne, ifl
      real ear(0:ne), param(6), photar(ne), photer(ne)

c This model convolves the input spectrum with
c the line profile from a Keplerian Accretion disk around
c both Schwarzschild & Kerr (arbitrary spin) black holes. In this case, the
c accretion disk is assumed to extend down to the marginally stable orbit for
c a particular black hole spin. The value of the spin parameter is determined
c by inversion of Rms(a) (see e.g. Bardeen, Press & Teulkolsky, 1974). The
c model can be used to fit to the value of Rms & hence determine a, which is
c displayed by setting chatter>=12 in XSPEC.
c
c It requires the use of an extensive set of transfer functions, which must be
c downloaded from the XSPEC website. These transfer functions should be placed
c in $LHEASOFT/../spectral/xspec/manager/XSKDLINE/
c
c The model accepts the following parameters:
c    1:  Rms      The location of the innermost stable orbit in units of GMc^{-2}
c                 This parameter can lie in the range 1.0 -> 6.0 & is used to
c                 determine the black hole spin, by inversion of Rms=Rms(a)
c    2:  Rout     The location of the outer edge of the disc in units of GMc^{-2}
c    3:  Incl     The inclination of the observer relative to the spin axis
c                 of the black hole in Degrees, in the range 1 (face-on) -> 89
c                 (edge-on), measured in degrees.
c    4:  Index    Index of radial power law used to generate the line, taken in
c                 the form r^{-index}
c    5:  F(r)     Specifies the type of radial emissivity, current options:
c                 0:  No dependence, F(r) = constant
c                 1:  Power law depence (see above)
c                 2:  Zero Torque IBC (Page & Thorne, 1974)
c    6:  G(m)     Specifies the type of angular emissivity, current options:
c                 0:  Optically thick, constant, G(m) = cons.
c                 1:  Optically thin, limb brightened, G(m) \propto 1/m
c                 2:  Optically thick, limb darkened, G(m) \propto (1+(2.06*m))/2.06
c                 3:  G(m) \propto m*log(1+m^{-1})
c                 For more info, see Beckwith & Done (2004)

      real eparam(8)

      integer i


      eparam(1)=0.0d0

      eparam(2)=param(1)

      eparam(3)=param(2)

      eparam(4)=param(3)

      eparam(5)=param(4)

      eparam(6)=param(5)

      eparam(7)=param(6)

      eparam(8)=0.0d0

      call xskdconv (ear, ne, eparam, ifl, photar, photer)

      param(1)=eparam(2)

      param(2)=eparam(3)

      param(3)=eparam(4)

      param(4)=eparam(5)

      param(5)=eparam(6)

      param(6)=eparam(7)


      return

      end
