      subroutine xskdl1 (ear,ne,param,ifl,photar,photer)

      implicit none

      integer ni,ngp,nc,ng,nr,np,nb
      parameter (ni=2,ngp=5,nc=2,ng=100,nr=100,np=5,nb=100)

      integer ne, ifl
      real ear(0:ne), param(8), photar(ne), photer(ne)

c This model calculates the line profile from a Keplerian Accretion disk around
c both Schwarzschild & Kerr (arbitrary spin) black holes. In this form, the
c model does not assume that the disk extends down to the innermost stable orbit
c Instead, the line profile is calculated by specifying the black spin, a; the
c inner (Rmin) & outer (Rmax) edges of the disk; along with inclination, etc.
c Due to the method used by XSPEC to perform spectral fitting, the radii are
c set in units such that Rms(a) = 1, Rout = 100. Unless the user is certain of
c what they are doing, it is STRONGLY advised that the spectral fit is started
c using the default settings of the model. Upon the completion of a fitting
c procedure, the user can determine the values of the radii in units of GMc^{-2}
c by setting chatter>=12.
c
c It requires the use of an extensive set of transfer functions, which must be
c downloaded from the XSPEC website. These transfer functions should be placed
c in $LHEASOFT/../spectral/xspec/manager/XSKDLINE/
c
c The model accepts the following parameters:
c    1:  Energy   Rest frame energy of the line
c    2:  Spin     Black hole spin, in range 0 (Schwarzschild) to 1 (Extreme Kerr)
c    3:  Rmin     Location of inner edge of accretion disk, in the range 1 to 100
c                 The units of this parameter are as described above
c    4:  Rmax     Location of outer edge of accretion disk, in the range 1 to 100
c                 The units of this parameter are as described above
c    5:  Incl     The inclination of the observer relative to the spin axis
c                 of the black hole in Degrees, in the range 1 (face-on) -> 89
c                 (edge-on), measured in degrees.
c    6:  Index    Index of radial power law used to generate the line, taken in
c                 the form r^{-index}
c    7:  F(r)     Specifies the type of radial emissivity, current options:
c                 0:  No dependence, F(r) = constant
c                 1:  Power law depence (see above)
c                 2:  Zero Torque IBC (Page & Thorne, 1974)
c    8:  G(m)     Specifies the type of angular emissivity, current options:
c                 0:  Optically thick, constant, G(m) = cons.
c                 1:  Optically thin, limb brightened, G(m) \propto 1/m
c                 2:  Optically thick, limb darkened, G(m) \propto (1+(2.06*m))/2.06
c                 3:  G(m) \propto m*log(1+m^{-1})
c                 For more info, see Beckwith & Done (2004)

      real eparam(9)

      integer i
      logical ccheck


      ccheck=.TRUE.

      eparam(1)=param(1)

      eparam(2)=param(2)

      eparam(3)=param(3)

      eparam(4)=param(4)

      eparam(5)=param(5)

      eparam(6)=param(6)

      eparam(7)=param(7)

      eparam(8)=param(8)

      eparam(9)=1.0d0

      call xskdline (ccheck, ear, ne, eparam, ifl, photar, photer)

      param(1)=eparam(1)

      param(2)=eparam(2)

      param(3)=eparam(3)

      param(4)=eparam(4)

      param(5)=eparam(5)

      param(6)=eparam(6)

      param(7)=eparam(7)

      param(8)=eparam(8)


      return

      end
